@@ -4,9 +4,10 @@ from prompt_toolkit.validation import Validator, ValidationError
 import questionary.version
 from questionary.form import Form
 from questionary.form import form
-from questionary.prompt import prompt
+from questionary.prompt import prompt, unsafe_prompt
 from questionary.prompts.common import Choice
 from questionary.prompts.common import Separator
+from questionary.prompts.common import print_formatted_text as print
 from questionary.question import Question
 
 # import the shortcuts to create single question prompts
@@ -14,9 +15,32 @@ from questionary.prompts.autocomplete import autocomplete
 from questionary.prompts.select import select
 from questionary.prompts.checkbox import checkbox
 from questionary.prompts.text import text
+from questionary.prompts.path import path
 from questionary.prompts.confirm import confirm
 from questionary.prompts.password import password
 from questionary.prompts.rawselect import rawselect
 
 
 __version__ = questionary.version.__version__
+
+__all__ = [
+    "Validator",
+    "ValidationError",
+    "Form",
+    "form",
+    "prompt",
+    "unsafe_prompt",
+    "Choice",
+    "Separator",
+    "Question",
+    "autocomplete",
+    "select",
+    "checkbox",
+    "text",
+    "confirm",
+    "password",
+    "print",
+    "path",
+    "rawselect",
+    "__version__",
+]
