@@ -1,5 +1,3 @@
-# -*- coding: utf-8 -*-
-
 from prompt_toolkit.styles import Style
 
 # Value to display as an answer when "affirming" a confirmation question
@@ -37,6 +35,7 @@ DEFAULT_STYLE = Style(
     [
         ("qmark", "fg:#5f819d"),  # token in front of the question
         ("question", "bold"),  # question text
+        ("text", ""),  # any other text
         ("answer", "fg:#FF9D00 bold"),  # submitted answer text behind the question
         ("pointer", ""),  # pointer used in select and checkbox prompts
         ("selected", ""),  # style for a selected item of a checkbox
